@@ -1,6 +1,7 @@
 import json
 import logging
 from datetime import datetime
+from pprint import pformat
 from typing import Dict, Optional
 
 from aiohttp import ClientSession
@@ -12,7 +13,7 @@ from pyhon.connection.auth import HonAuth
 from pyhon.connection.handler.anonym import HonAnonymousConnectionHandler
 from pyhon.connection.handler.hon import HonConnectionHandler
 
-_LOGGER = logging.getLogger()
+_LOGGER = logging.getLogger(__name__)
 
 
 class HonAPI:
@@ -72,20 +73,23 @@ class HonAPI:
     async def load_commands(self, appliance: HonAppliance) -> Dict:
         params: Dict = {
             "applianceType": appliance.appliance_type,
-            "code": appliance.info["code"],
             "applianceModelId": appliance.appliance_model_id,
             "macAddress": appliance.mac_address,
-            "fwVersion": appliance.info["fwVersion"],
             "os": const.OS,
             "appVersion": const.APP_VERSION,
-            "series": appliance.info["series"],
+            "code": appliance.code,
         }
         if firmware_id := appliance.info.get("eepromId"):
             params["firmwareId"] = firmware_id
+        if firmware_version := appliance.info.get("fwVersion"):
+            params["fwVersion"] = firmware_version
+        if series := appliance.info.get("series"):
+            params["series"] = series
         url: str = f"{const.API_URL}/commands/v1/retrieve"
         async with self._hon.get(url, params=params) as response:
             result: Dict = (await response.json()).get("payload", {})
             if not result or result.pop("resultCode") != "0":
+                _LOGGER.error(await response.json())
                 return {}
             return result
 
@@ -99,6 +103,16 @@ class HonAPI:
                 return {}
             return result["payload"]["history"]
 
+    async def command_favourites(self, appliance: HonAppliance) -> Dict:
+        url: str = (
+            f"{const.API_URL}/commands/v1/appliance/{appliance.mac_address}/favourite"
+        )
+        async with self._hon.get(url) as response:
+            result: Dict = await response.json()
+            if not result or not result.get("payload"):
+                return {}
+            return result["payload"]["favourites"]
+
     async def last_activity(self, appliance: HonAppliance) -> Dict:
         url: str = f"{const.API_URL}/commands/v1/retrieve-last-activity"
         params: Dict = {"macAddress": appliance.mac_address}
@@ -108,6 +122,18 @@ class HonAPI:
                 return activity
         return {}
 
+    async def appliance_model(self, appliance: HonAppliance) -> Dict:
+        url: str = f"{const.API_URL}/commands/v1/appliance-model"
+        params: Dict = {
+            "code": appliance.info["code"],
+            "macAddress": appliance.mac_address,
+        }
+        async with self._hon.get(url, params=params) as response:
+            result: Dict = await response.json()
+            if result and (activity := result.get("attributes")):
+                return activity
+        return {}
+
     async def load_attributes(self, appliance: HonAppliance) -> Dict:
         params: Dict = {
             "macAddress": appliance.mac_address,
@@ -127,6 +153,12 @@ class HonAPI:
         async with self._hon.get(url, params=params) as response:
             return (await response.json()).get("payload", {})
 
+    async def load_maintenance(self, appliance: HonAppliance):
+        url = f"{const.API_URL}/commands/v1/maintenance-cycle"
+        params = {"macAddress": appliance.mac_address}
+        async with self._hon.get(url, params=params) as response:
+            return (await response.json()).get("payload", {})
+
     async def send_command(
         self,
         appliance: HonAppliance,
@@ -140,7 +172,7 @@ class HonAPI:
             "timestamp": f"{now[:-3]}Z",
             "commandName": command,
             "transactionId": f"{appliance.mac_address}_{now[:-3]}Z",
-            "applianceOptions": appliance.commands_options,
+            "applianceOptions": appliance.options,
             "device": self._hon.device.get(mobile=True),
             "attributes": {
                 "channel": "mobileApp",
@@ -157,10 +189,11 @@ class HonAPI:
             if json_data.get("payload", {}).get("resultCode") == "0":
                 return True
             _LOGGER.error(await response.text())
+            _LOGGER.error("%s - Payload:\n%s", url, pformat(data))
         return False
 
     async def appliance_configuration(self) -> Dict:
-        url: str = f"{const.API_URL}/config/v1/appliance-configuration"
+        url: str = f"{const.API_URL}/config/v1/program-list-rules"
         async with self._hon_anonymous.get(url) as response:
             result: Dict = await response.json()
             if result and (data := result.get("payload")):
