@@ -1,11 +1,11 @@
-from typing import Dict, Any, List
+from typing import Dict, Any
 
 from pyhon.parameter.base import HonParameter
 
 
 class HonParameterFixed(HonParameter):
-    def __init__(self, key: str, attributes: Dict[str, Any]) -> None:
-        super().__init__(key, attributes)
+    def __init__(self, key: str, attributes: Dict[str, Any], group: str) -> None:
+        super().__init__(key, attributes, group)
         self._value = attributes.get("fixedValue", None)
 
     def __repr__(self) -> str:
@@ -19,7 +19,4 @@ class HonParameterFixed(HonParameter):
     def value(self, value: str | float) -> None:
         # Fixed values seems being not so fixed as thought
         self._value = value
-
-    @property
-    def values(self) -> List[str]:
-        return list(str(self.value))
+        self.check_trigger(value)
